# Dots

![MIT license][badge-license]
![maintained?][badge-maintained]
[![Code Style: Black][badge-code-style]][black]

An easier way for syncing and updating dotfiles, making it more fun!

## Installation

[Like any other Python package][installing-guide]:

```
pip install dots
```

## Usage

### Layout

### Commands

```
$ dots sync
```

```
$ dots clean
```

```
$ dots check
```

[black]: https://github.com/psf/black
[installing-guide]: https://packaging.python.org/tutorials/installing-packages/

[badge-code-style]: https://img.shields.io/badge/code%20style-black-000000.svg
[badge-maintained]: https://img.shields.io/maintenance/yes/2019.svg
[badge-license]: https://img.shields.io/badge/license-MIT-brightgreen.svg
